@@ -1,24 +1,30 @@
-/* Nautilus Actions configuration tool
- * Copyright (C) 2005 The GNOME Foundation
+/*
+ * Nautilus Actions
  *
- * Authors:
- *  Frederic Ruaudel (grumz@grumz.net)
- *	 Rodrigo Moya (rodrigo@gnome-db.org)
+ * Copyright (C) 2005 The GNOME Foundation
+ * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
  *
  * This Program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
  * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * write to the Free Software Foundation, Inc., 59 Temple Place,
+ * Suite 330, Boston, MA 02111-1307, USA.
+ *
+ * Authors:
+ *   Frederic Ruaudel <grumz@grumz.net>
+ *   Rodrigo Moya <rodrigo@gnome-db.org>
+ *   Pierre Wieser <pwieser@trychlos.org>
+ *   ... and many others (see AUTHORS)
  */
 
 #include <config.h>
@@ -31,13 +37,21 @@
 #include <libnautilus-actions/nautilus-actions-config-schema-reader.h>
 #include <libnautilus-actions/nautilus-actions-config-schema-writer.h>
 #include <libnautilus-actions/nautilus-actions-config-gconf-writer.h>
-#include <libnautilus-actions/nautilus-actions-config-xml.h>
 #include "nact-utils.h"
 #include "nact-import-export.h"
 #include "nact-prefs.h"
 #include "nact.h"
 
-void mode_toggled_cb (GtkWidget* widget, gpointer user_data)
+/* gui callback functions */
+void import_browse_button_clicked_cb (GtkWidget* widget, gpointer data);
+void export_browse_button_clicked_cb (GtkWidget* widget, gpointer data);
+void mode_toggled_cb (GtkWidget* widget, gpointer user_data);
+
+static gboolean nact_import_actions (void);
+static gboolean nact_export_actions (void);
+
+void
+mode_toggled_cb (GtkWidget* widget, gpointer user_data)
 {
 	GtkWidget* import_radio = nact_get_glade_widget_from ("ImportRadioButton", GLADE_IM_EX_PORT_DIALOG_WIDGET);
 
@@ -53,23 +67,8 @@ void mode_toggled_cb (GtkWidget* widget, gpointer user_data)
 	}
 }
 
-void import_all_config_toggled_cb (GtkWidget* check_button, gpointer data) 
-{
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_button)))
-	{
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (nact_get_glade_widget_from ("XMLRadioButton", 
-																			GLADE_IM_EX_PORT_DIALOG_WIDGET)), TRUE);
-		gtk_widget_set_sensitive (nact_get_glade_widget_from ("FileHBox", GLADE_IM_EX_PORT_DIALOG_WIDGET), FALSE);
-		gtk_widget_set_sensitive (nact_get_glade_widget_from ("TypeConfigVBox", GLADE_IM_EX_PORT_DIALOG_WIDGET), FALSE);
-	}
-	else
-	{
-		gtk_widget_set_sensitive (nact_get_glade_widget_from ("FileHBox", GLADE_IM_EX_PORT_DIALOG_WIDGET), TRUE);
-		gtk_widget_set_sensitive (nact_get_glade_widget_from ("TypeConfigVBox", GLADE_IM_EX_PORT_DIALOG_WIDGET), TRUE);
-	}
-}
-
-void import_browse_button_clicked_cb (GtkWidget* widget, gpointer data)
+void
+import_browse_button_clicked_cb (GtkWidget* widget, gpointer data)
 {
 	gchar* last_dir;
 	gchar* filename;
@@ -82,7 +81,7 @@ void import_browse_button_clicked_cb (GtkWidget* widget, gpointer data)
 	{
 		set_current_location = gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (filechooser), filename);
 	}
-	
+
 	if (!set_current_location)
 	{
 		last_dir = nact_prefs_get_import_last_browsed_dir ();
@@ -90,7 +89,7 @@ void import_browse_button_clicked_cb (GtkWidget* widget, gpointer data)
 		g_free (last_dir);
 	}
 
-	switch (gtk_dialog_run (GTK_DIALOG (filechooser))) 
+	switch (gtk_dialog_run (GTK_DIALOG (filechooser)))
 	{
 		case GTK_RESPONSE_OK :
 			last_dir = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (filechooser));
@@ -103,10 +102,11 @@ void import_browse_button_clicked_cb (GtkWidget* widget, gpointer data)
 		case GTK_RESPONSE_CANCEL:
 		case GTK_RESPONSE_DELETE_EVENT:
 			gtk_widget_hide (filechooser);
-	}	
+	}
 }
 
-void export_browse_button_clicked_cb (GtkWidget* widget, gpointer data) 
+void
+export_browse_button_clicked_cb (GtkWidget* widget, gpointer data)
 {
 	gchar* last_dir;
 	gchar* foldername;
@@ -119,7 +119,7 @@ void export_browse_button_clicked_cb (GtkWidget* widget, gpointer data)
 	{
 		set_current_location = gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (folderchooser), foldername);
 	}
-	
+
 	if (!set_current_location)
 	{
 		last_dir = nact_prefs_get_export_last_browsed_dir ();
@@ -127,7 +127,7 @@ void export_browse_button_clicked_cb (GtkWidget* widget, gpointer data)
 		g_free (last_dir);
 	}
 
-	switch (gtk_dialog_run (GTK_DIALOG (folderchooser))) 
+	switch (gtk_dialog_run (GTK_DIALOG (folderchooser)))
 	{
 		case GTK_RESPONSE_OK :
 			last_dir = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (folderchooser));
@@ -140,17 +140,16 @@ void export_browse_button_clicked_cb (GtkWidget* widget, gpointer data)
 		case GTK_RESPONSE_CANCEL:
 		case GTK_RESPONSE_DELETE_EVENT:
 			gtk_widget_hide (folderchooser);
-	}	
+	}
 }
 
-
 static void
 list_selection_changed_cb (GtkTreeSelection *selection, gpointer user_data)
 {
 /*
 	GtkWidget *nact_edit_button;
 	GtkWidget *nact_delete_button;
-	
+
 	nact_edit_button = nact_get_glade_widget ("EditActionButton");
 	nact_delete_button = nact_get_glade_widget ("DeleteActionButton");
 
@@ -188,21 +187,20 @@ static void nact_setup_actions_list (GtkWidget *list)
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (list));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
-	
+
 	/* set up selection */
 	g_signal_connect (G_OBJECT (gtk_tree_view_get_selection (GTK_TREE_VIEW (list))), "changed",
 			  G_CALLBACK (list_selection_changed_cb), NULL);
 
 }
 
-gboolean nact_import_actions (void)
+static gboolean
+nact_import_actions (void)
 {
 	gboolean retv = FALSE;
-	GtkWidget* check_button;
 	GSList* iter;
 	NautilusActionsConfigGconfWriter *config;
 	NautilusActionsConfigSchemaReader *schema_reader;
-	NautilusActionsConfigXml* xml_reader;
 	NautilusActionsConfig* generic_reader = NULL;
 	gchar* error_message;
 	GError* error = NULL;
@@ -211,68 +209,20 @@ gboolean nact_import_actions (void)
 
 	config = nautilus_actions_config_gconf_writer_get ();
 	schema_reader = nautilus_actions_config_schema_reader_get ();
-	nautilus_actions_config_clear (schema_reader);
-	xml_reader = nautilus_actions_config_xml_get ();
-	nautilus_actions_config_clear (xml_reader);
+	nautilus_actions_config_clear(( NautilusActionsConfig * ) schema_reader );
 
-	check_button = nact_get_glade_widget_from ("ImportAllCheckButton", GLADE_IM_EX_PORT_DIALOG_WIDGET);
-
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check_button)))
+	if (file_path != NULL && strlen (file_path) > 0)
 	{
-		nautilus_actions_config_xml_load_list (xml_reader);
-		generic_reader = NAUTILUS_ACTIONS_CONFIG (xml_reader);
-	}
-	else if (file_path != NULL && strlen (file_path) > 0)
-	{
-		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (nact_get_glade_widget_from ("XMLRadioButton", 
-																			GLADE_IM_EX_PORT_DIALOG_WIDGET))))
+		if (nautilus_actions_config_schema_reader_parse_file (schema_reader, file_path, &error))
 		{
-			if (nautilus_actions_config_xml_parse_file (xml_reader, file_path, &error))
-			{
-				generic_reader = NAUTILUS_ACTIONS_CONFIG (xml_reader);
-			}
-			else
-			{
-				error_message = g_strdup_printf (_("Can't parse file '%s' as old XML config file !"), file_path);
-				nautilus_actions_display_error (error_message, error->message);
-				g_error_free (error);
-				g_free (error_message);
-			}
+			generic_reader = NAUTILUS_ACTIONS_CONFIG (schema_reader);
 		}
-		else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (nact_get_glade_widget_from ("GConfRadioButton", 
-																			GLADE_IM_EX_PORT_DIALOG_WIDGET))))
+		else
 		{
-			if (nautilus_actions_config_schema_reader_parse_file (schema_reader, file_path, &error))
-			{
-				generic_reader = NAUTILUS_ACTIONS_CONFIG (schema_reader);
-			}
-			else
-			{
-				error_message = g_strdup_printf (_("Can't parse file '%s' as GConf schema description file !"), file_path);
-				nautilus_actions_display_error (error_message, error->message);
-				g_error_free (error);
-				g_free (error_message);
-			}
-		}
-		else /* Automatic detection asked */
-		{
-			//--> we are ignoring the first error because if it fails here it will not in the next 
-			// or if both fails, we kept the current GConf config format as the most important
-			if (nautilus_actions_config_xml_parse_file (xml_reader, file_path, NULL))
-			{
-				generic_reader = NAUTILUS_ACTIONS_CONFIG (xml_reader);
-			}
-			else if (nautilus_actions_config_schema_reader_parse_file (schema_reader, file_path, &error))
-			{
-				generic_reader = NAUTILUS_ACTIONS_CONFIG (schema_reader);
-			}
-			else
-			{
-				error_message = g_strdup_printf (_("Can't parse file '%s' !"), file_path);
-				nautilus_actions_display_error (error_message, error->message);
-				g_error_free (error);
-				g_free (error_message);
-			}
+			error_message = g_strdup_printf (_("Can't parse file '%s' as GConf schema description file!"), file_path);
+			nautilus_actions_display_error (error_message, error->message);
+			g_error_free (error);
+			g_free (error_message);
 		}
 	}
 
@@ -289,19 +239,19 @@ gboolean nact_import_actions (void)
 			}
 			else
 			{
-				// i18n notes: %s is the label of the action (eg, 'Mount ISO')
-				error_message = g_strdup_printf (_("Action '%s' importation failed !"), action->label);
+				/* i18n notes: %s is the label of the action (eg, 'Mount ISO') */
+				error_message = g_strdup_printf (_("Action '%s' importation failed!"), action->label);
 				nautilus_actions_display_error (error_message, error->message);
 				g_error_free (error);
 				g_free (error_message);
 			}
 		}
 	}
-
 	return retv;
 }
 
-gboolean nact_export_actions (void)
+static gboolean
+nact_export_actions (void)
 {
 	gboolean retv = FALSE;
 	GtkTreeSelection *selection;
@@ -334,10 +284,10 @@ gboolean nact_export_actions (void)
 			gtk_tree_model_get (model, &iter, UUID_COLUMN, &uuid, -1);
 
 			action = nautilus_actions_config_get_action (NAUTILUS_ACTIONS_CONFIG (config), uuid);
-			// TODO: Better error handling: deal with the GError param
+			/* TODO: Better error handling: deal with the GError param */
 			if (nautilus_actions_config_add_action (NAUTILUS_ACTIONS_CONFIG (schema_writer), action, NULL))
 			{
-				nautilus_actions_config_schema_writer_get_saved_filename (schema_writer, action->uuid);
+				/*nautilus_actions_config_schema_writer_get_saved_filename (schema_writer, action->uuid);*/
 			}
 
 			g_free (uuid);
@@ -347,7 +297,7 @@ gboolean nact_export_actions (void)
 		g_list_free (selection_list);
 		retv = TRUE;
 	}
-	
+
 	if (retv)
 	{
 		gchar* command = g_strdup_printf ("nautilus %s", save_path);
@@ -380,12 +330,12 @@ gboolean nact_import_export_actions (void)
 			g_error (_("Could not load interface for Nautilus Actions Config Tool"));
 			return FALSE;
 		}
-		
+
 		glade_xml_signal_autoconnect (gui);
 
 		nact_action_list_tree = nact_get_glade_widget_from ("ExportTreeView", GLADE_IM_EX_PORT_DIALOG_WIDGET);
 		nact_setup_actions_list (nact_action_list_tree);
-		
+
 		aligned_widgets = nact_get_glade_widget_prefix_from ("IELabelAlign", GLADE_IM_EX_PORT_DIALOG_WIDGET);
 		label_size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 		for (iter = aligned_widgets; iter; iter = iter->next)
@@ -393,11 +343,11 @@ gboolean nact_import_export_actions (void)
 			gtk_size_group_add_widget (label_size_group, GTK_WIDGET (iter->data));
 		}
 		button_size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-		gtk_size_group_add_widget (button_size_group, 
-											nact_get_glade_widget_from ("ImportBrowseButton", 
+		gtk_size_group_add_widget (button_size_group,
+											nact_get_glade_widget_from ("ImportBrowseButton",
 																		GLADE_IM_EX_PORT_DIALOG_WIDGET));
-		gtk_size_group_add_widget (button_size_group, 
-											nact_get_glade_widget_from ("ExportBrowseButton", 
+		gtk_size_group_add_widget (button_size_group,
+											nact_get_glade_widget_from ("ExportBrowseButton",
 																		GLADE_IM_EX_PORT_DIALOG_WIDGET));
 		/* free memory */
 		g_object_unref (gui);
@@ -413,10 +363,10 @@ gboolean nact_import_export_actions (void)
 
 	/* Get the default dialog size */
 	gtk_window_get_default_size (GTK_WINDOW (import_export_dialog), &width, &height);
-	
+
 	/* Override with preferred one, if any */
 	nact_prefs_get_im_ex_dialog_size (&width, &height);
-	
+
 	gtk_window_resize (GTK_WINDOW (import_export_dialog), width, height);
 
 	if (nact_prefs_get_im_ex_dialog_position (&x, &y))
@@ -426,10 +376,10 @@ gboolean nact_import_export_actions (void)
 
 	last_dir = nact_prefs_get_export_last_browsed_dir ();
 	gtk_entry_set_text (GTK_ENTRY (nact_get_glade_widget_from ("ExportEntry", GLADE_IM_EX_PORT_DIALOG_WIDGET)), last_dir);
-	gtk_entry_select_region (GTK_ENTRY (nact_get_glade_widget_from ("ExportEntry", GLADE_IM_EX_PORT_DIALOG_WIDGET)), 0, -1);
-	
+	gtk_editable_select_region (GTK_EDITABLE (nact_get_glade_widget_from ("ExportEntry", GLADE_IM_EX_PORT_DIALOG_WIDGET)), 0, -1);
+
 	/* run the dialog */
-	switch (gtk_dialog_run (GTK_DIALOG (import_export_dialog))) 
+	switch (gtk_dialog_run (GTK_DIALOG (import_export_dialog)))
 	{
 		case GTK_RESPONSE_OK :
 			if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (import_radio)))
@@ -456,5 +406,3 @@ gboolean nact_import_export_actions (void)
 
 	return retv;
 }
-
-// vim:ts=3:sw=3:tw=1024:cin
