@@ -1,28 +1,34 @@
-/* Nautilus Actions configuration tool
- * Copyright (C) 2005 The GNOME Foundation
+/*
+ * Nautilus Actions
  *
- * Authors:
- *  Frederic Ruaudel (grumz@grumz.net)
- *	 Rodrigo Moya (rodrigo@gnome-db.org)
+ * Copyright (C) 2005 The GNOME Foundation
+ * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
  *
  * This Program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public
  * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * write to the Free Software Foundation, Inc., 59 Temple Place,
+ * Suite 330, Boston, MA 02111-1307, USA.
+ *
+ * Authors:
+ *   Frederic Ruaudel <grumz@grumz.net>
+ *   Rodrigo Moya <rodrigo@gnome-db.org>
+ *   Pierre Wieser <pwieser@trychlos.org>
+ *   ... and many others (see AUTHORS)
  */
 
-#ifndef NAUTILUS_ACTIONS_H
-#define NAUTILUS_ACTIONS_H
+#ifndef __NAUTILUS_ACTIONS_H__
+#define __NAUTILUS_ACTIONS_H__
 
 #include <glib-object.h>
 #include <libnautilus-actions/nautilus-actions-config-gconf-reader.h>
@@ -39,7 +45,7 @@ G_BEGIN_DECLS
 typedef struct _NautilusActions	NautilusActions;
 typedef struct _NautilusActionsClass NautilusActionsClass;
 
-struct _NautilusActions 
+struct _NautilusActions
 {
 	GObject __parent;
 	NautilusActionsConfigGconfReader* configs;
@@ -52,11 +58,9 @@ struct _NautilusActionsClass
 	GObjectClass __parent;
 };
 
-GType nautilus_actions_get_type (void);
-void nautilus_actions_register_type (GTypeModule *module);
+GType	nautilus_actions_get_type (void);
+void	nautilus_actions_register_type (GTypeModule *module);
 
 G_END_DECLS
 
-#endif /* NAUTILUS_ACTIONS_H */
-
-// vim:ts=3:sw=3:tw=1024
+#endif /* __NAUTILUS_ACTIONS_H__ */
